@@ -95,22 +95,19 @@ static void
 begin (HTMLPainter *painter, int x1, int y1, int x2, int y2)
 {
 	HTMLGdkPainter *gdk_painter;
-	GdkVisual *visual;
 
 	/* printf ("painter begin %d,%d %d,%d\n", x1, y1, x2, y2); */
 
 	gdk_painter = HTML_GDK_PAINTER (painter);
 	g_return_if_fail (gdk_painter->window != NULL);
-	visual = gdk_drawable_get_visual (gdk_painter->window);
-	g_return_if_fail (visual != NULL);
 
 	if (gdk_painter->double_buffer){
 		const int width = x2 - x1 + 1;
 		const int height = y2 - y1 + 1;
 
 		g_assert (gdk_painter->pixmap == NULL);
-		
-		gdk_painter->pixmap = gdk_pixmap_new (gdk_painter->pixmap, width, height, visual->depth);
+
+		gdk_painter->pixmap = gdk_pixmap_new (gdk_painter->window, width, height, -1);
 		gdk_painter->x1 = x1;
 		gdk_painter->y1 = y1;
 		gdk_painter->x2 = x2;
@@ -131,6 +128,8 @@ begin (HTMLPainter *painter, int x1, int y1, int x2, int y2)
 		gdk_painter->x2 = 0;
 		gdk_painter->y2 = 0;
 	}
+
+	g_return_if_fail (gdk_drawable_get_colormap (gdk_painter->pixmap) != NULL);
 }
 
 static void
