@@ -34,8 +34,10 @@ struct _HTMLTextSlave {
 	HTMLText *owner;
 	guint posStart;
 	guint posLen;
-	guint start_word;
 	gchar *charStart;
+
+	HTMLTextPangoInfo *pi;
+	GList *glyphs;
 };
 
 struct _HTMLTextSlaveClass {
@@ -50,14 +52,11 @@ void        html_text_slave_init                  (HTMLTextSlave      *slave,
 						   HTMLTextSlaveClass *klass,
 						   HTMLText           *owner,
 						   guint               posStart,
-						   guint               posLen,
-						   guint               start_word);
+						   guint               posLen);
 HTMLObject *html_text_slave_new                   (HTMLText           *owner,
 						   guint               posStart,
-						   guint               posLen,
-						   guint               start_word);
+						   guint               posLen);
 gint        html_text_slave_get_line_offset       (HTMLTextSlave      *slave,
-						   gint                line_offset,
 						   gint                offset,
 						   HTMLPainter        *p);
 char       *html_text_slave_get_text              (HTMLTextSlave      *slave);
@@ -70,4 +69,10 @@ gchar      *html_text_slave_remove_leading_space  (HTMLTextSlave      *slave,
 gint        html_text_slave_get_nb_width          (HTMLTextSlave      *slave,
 						   HTMLPainter        *painter,
 						   gboolean            lineBegin);
+GList      *html_get_glyphs_non_tab               (GList              *glyphs,
+						   PangoItem          *item,
+						   gint                ii,
+						   const gchar        *text,
+						   gint                bytes,
+						   gint                len);
 #endif /* _HTMLTEXTSLAVE_H_ */
